==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/en_us.js <==
/**
 * English spoken in the US
 */

$.Editable.LANGS['en_us'] = {
  translation: {
    "Bold": "Bold",
    "Italic": "Italic",
    "Underline": "Underline",
    "Strikethrough": "Strikethrough",
    "Font Size": "Font Size",
    "Color": "Color",
    "Background Color": "Background Color",
    "Text Color": "Text Color",
    "Format Block": "Format Block",
    "Normal": "Normal",
    "Paragraph": "Paragraph",
    "Code": "Code",
    "Quote": "Quote",
    "Heading 1": "Heading 1",
    "Heading 2": "Heading 2",
    "Heading 3": "Heading 3",
    "Heading 4": "Heading 4",
    "Heading 5": "Heading 5",
    "Heading 6": "Heading 6",
    "Alignment": "Alignment",
    "Align Left": "Align Left",
    "Align Center": "Align Center",
    "Align Right": "Align Right",
    "Justify": "Justify",
    "Numbered List": "Numbered List",
    "Bulleted List": "Bulleted List",
    "Indent Less": "Indent Less",
    "Indent More": "Indent More",
    "Select All": "Select All",
    "Insert Link": "Insert Link",
    "Insert Image": "Insert Image",
    "Insert Video": "Insert Video",
    "Undo": "Undo",
    "Redo": "Redo",
    "Show HTML": "Show HTML",
    "Float Left": "Float Left",
    "Float None": "Float None",
    "Float Right": "Float Right",
    "Replace Image": "Replace Image",
    "Remove Image": "Remove Image",
    "Title": "Title",
    "Insert image": "Insert image",
    "Drop image": "Drop image",
    "or click": "or click",
    "Enter URL": "Enter URL",
    "Please wait!": "Please wait!",
    "Are you sure? Image will be deleted.": "Are you sure? Image will be deleted.",
    "UNLINK": "UNLINK",
    "Open in new tab": "Open in new tab",
    "Type something": "Type something",
    "Cancel": "Cancel",
    "OK": "OK",
    "Manage images": "Manage images",
    "Delete": "Delete",
    "Font Family": "Font family",
    "Insert Horizontal Line": "Insert Horizontal Line"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.3.tar.gz: django-froala-editor-0.8.3/froala_editor/static/froala_editor/js/langs/en_us.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * English spoken in the US
 */

$.Editable.LANGS['en_us'] = {
  translation: {
    "Bold": "Bold",
    "Italic": "Italic",
    "Underline": "Underline",
    "Strikethrough": "Strikethrough",
    "Font Size": "Font Size",
    "Color": "Color",
    "Background Color": "Background Color",
    "Text Color": "Text Color",
    "Format Block": "Format Block",
    "Normal": "Normal",
    "Paragraph": "Paragraph",
    "Code": "Code",
    "Quote": "Quote",
    "Heading 1": "Heading 1",
    "Heading 2": "Heading 2",
    "Heading 3": "Heading 3",
    "Heading 4": "Heading 4",
    "Heading 5": "Heading 5",
    "Heading 6": "Heading 6",
    "Alignment": "Alignment",
    "Align Left": "Align Left",
    "Align Center": "Align Center",
    "Align Right": "Align Right",
    "Justify": "Justify",
    "Numbered List": "Numbered List",
    "Bulleted List": "Bulleted List",
    "Indent Less": "Indent Less",
    "Indent More": "Indent More",
    "Select All": "Select All",
    "Insert Link": "Insert Link",
    "Insert Image": "Insert Image",
    "Insert Video": "Insert Video",
    "Undo": "Undo",
    "Redo": "Redo",
    "Show HTML": "Show HTML",
    "Float Left": "Float Left",
    "Float None": "Float None",
    "Float Right": "Float Right",
    "Replace Image": "Replace Image",
    "Remove Image": "Remove Image",
    "Title": "Title",
    "Insert image": "Insert image",
    "Drop image": "Drop image",
    "or click": "or click",
    "Enter URL": "Enter URL",
    "Please wait!": "Please wait!",
    "Are you sure? Image will be deleted.": "Are you sure? Image will be deleted.",
    "UNLINK": "UNLINK",
    "Open in new tab": "Open in new tab",
    "Type something": "Type something",
    "Cancel": "Cancel",
    "OK": "OK",
    "Manage images": "Manage images",
    "Delete": "Delete",
    "Font Family": "Font family",
    "Insert Horizontal Line": "Insert Horizontal Line",
    "Table": "Table",
    "Insert table": "Insert table",
    "Cell": "Cell",
    "Row": "Row",
    "Column": "Column",
    "Delete table": "Delete table",
    "Insert cell before": "Insert cell before",
    "Insert cell after": "Insert cell after",
    "Delete cell": "Delete cell",
    "Merge cells": "Merge cells",
    "Horizontal split": "Horizontal split",
    "Vertical split": "Vertical split",
    "Insert row above": "Insert row above",
    "Insert row below": "Insert row below",
    "Delete row": "Delete row",
    "Insert column before": "Insert column before",
    "Insert column after": "Insert column after",
    "Delete column": "Delete column"
  },
  direction: "ltr"
};
